Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/gizmo_simpletest.py
    :caption: examples/gizmo_simpletest.py
    :linenos:

Other examples
---------------

.. literalinclude:: ../examples/gizmo_tft_demo.py
    :caption: examples/gizmo_tft_demo.py
    :linenos:

.. literalinclude:: ../examples/gizmo_tft_thermometer.py
    :caption: examples/gizmo_tft_thermometer.py
    :linenos:

.. literalinclude:: ../examples/gizmo_eink_simpletest.py
    :caption: examples/gizmo_eink_simpletest.py
    :linenos:
